/*
 mpgaud.h
*/

#include "../mpg123.h"

#define MPG_MAX_SAMPLES		1152

#if TARGET_OS_MAC
 #include <Sound.h>
 #include <Timer.h>
#else
 #include "mevent.h"
#endif
typedef struct mpgaud_channel
{
#if TARGET_OS_MAC
	TMTask		task; /* used in real-time case */
	CmpSoundHeader	header;
	uint8		chSize;
#else
	timerEntry	*task;
	int8		*samplePtr;
	int32		numFrames;
	uint8		chCount, chSize;
	boolean		busy;
#endif
	boolean		done;

	struct SndChannel	*channel; /* use stop+pauseCmd / resumeCmd for pause/resume */

	mpg123_handle	*stream;
	/* samplePtr points to the next play */
	long		rate;
	int16		bufcount;
	int16		bufindex;
	int32		buftotal;
	int8		*buffer, *midptr;
 #ifdef env68k
	long		myA5;
 #endif
} mpgaud_channel;

/* makes sure everything is allocated and reset */
/* can be called more than once with the same mpgaud_channel* */
/* returns error code, 0 if SndChannel failed, or 1 on success */
extern int mpgaud_audioinit(struct mpgaud_channel**,
	mpg123_handle *mpgh,
	int16 bufcount); /* pass negative for autoplay */
/* calls mpgaud_decode_frame, updates counters */
/* plays when full or when time is up already playing */
/* returns error code, 0 if not yet playing, 1 or 2 if playing */
extern int mpgaud_audiobuffer(struct mpgaud_channel*);
/* disposes of the contents of the channel */
/* DOES NOT close the mpgaud_STREAM */
/* returns error code, or total count deallocated */
extern int mpgaud_audioclose(struct mpgaud_channel*);
/* stops buffering and playback (until mpgaud_audiobuffer) */
/* returns error code or 0 */
int mpgaud_audiostop(mpgaud_channel *chan);
